import * as React from "react";
import type { HydrationState, InitialEntry, Location, RouteMatch, RouteObject, Router as DataRouter, To } from "@remix-run/router";
import { Action as NavigationType } from "@remix-run/router";
import { Navigator } from "./context";
import type { ResolvedDeferrable } from "./hooks";
/**
 * Unit-testing-only function to reset the router between tests
 * @private
 */
export declare function _resetModuleScope(): void;
/**
 * @private
 */
export declare function useRenderDataRouter({ basename, children, fallbackElement, routes, createRouter, }: {
    basename?: string;
    children?: React.ReactNode;
    fallbackElement?: React.ReactNode;
    routes?: RouteObject[];
    createRouter: (routes: RouteObject[]) => DataRouter;
}): React.ReactElement;
export interface DataMemoryRouterProps {
    basename?: string;
    children?: React.ReactNode;
    initialEntries?: InitialEntry[];
    initialIndex?: number;
    hydrationData?: HydrationState;
    fallbackElement?: React.ReactNode;
    routes?: RouteObject[];
}
export declare function DataMemoryRouter({ basename, children, initialEntries, initialIndex, hydrationData, fallbackElement, routes, }: DataMemoryRouterProps): React.ReactElement;
export interface MemoryRouterProps {
    basename?: string;
    children?: React.ReactNode;
    initialEntries?: InitialEntry[];
    initialIndex?: number;
}
/**
 * A <Router> that stores all entries in memory.
 *
 * @see https://reactrouter.com/docs/en/v6/routers/memory-router
 */
export declare function MemoryRouter({ basename, children, initialEntries, initialIndex, }: MemoryRouterProps): React.ReactElement;
export interface NavigateProps {
    to: To;
    replace?: boolean;
    state?: any;
}
/**
 * Changes the current location.
 *
 * Note: This API is mostly useful in React.Component subclasses that are not
 * able to use hooks. In functional components, we recommend you use the
 * `useNavigate` hook instead.
 *
 * @see https://reactrouter.com/docs/en/v6/components/navigate
 */
export declare function Navigate({ to, replace, state }: NavigateProps): null;
export interface OutletProps {
    context?: unknown;
}
/**
 * Renders the child route's element, if there is one.
 *
 * @see https://reactrouter.com/docs/en/v6/components/outlet
 */
export declare function Outlet(props: OutletProps): React.ReactElement | null;
interface DataRouteProps {
    id?: RouteObject["id"];
    loader?: RouteObject["loader"];
    action?: RouteObject["action"];
    errorElement?: RouteObject["errorElement"];
    shouldRevalidate?: RouteObject["shouldRevalidate"];
    handle?: RouteObject["handle"];
}
export interface RouteProps extends DataRouteProps {
    caseSensitive?: boolean;
    children?: React.ReactNode;
    element?: React.ReactNode | null;
    index?: boolean;
    path?: string;
}
export interface PathRouteProps extends DataRouteProps {
    caseSensitive?: boolean;
    children?: React.ReactNode;
    element?: React.ReactNode | null;
    index?: false;
    path: string;
}
export interface LayoutRouteProps extends DataRouteProps {
    children?: React.ReactNode;
    element?: React.ReactNode | null;
}
export interface IndexRouteProps extends DataRouteProps {
    element?: React.ReactNode | null;
    index: true;
}
/**
 * Declares an element that should be rendered at a certain URL path.
 *
 * @see https://reactrouter.com/docs/en/v6/components/route
 */
export declare function Route(_props: PathRouteProps | LayoutRouteProps | IndexRouteProps): React.ReactElement | null;
export interface RouterProps {
    basename?: string;
    children?: React.ReactNode;
    location: Partial<Location> | string;
    navigationType?: NavigationType;
    navigator: Navigator;
    static?: boolean;
}
/**
 * Provides location context for the rest of the app.
 *
 * Note: You usually won't render a <Router> directly. Instead, you'll render a
 * router that is more specific to your environment such as a <BrowserRouter>
 * in web browsers or a <StaticRouter> for server rendering.
 *
 * @see https://reactrouter.com/docs/en/v6/routers/router
 */
export declare function Router({ basename: basenameProp, children, location: locationProp, navigationType, navigator, static: staticProp, }: RouterProps): React.ReactElement | null;
export interface RoutesProps {
    children?: React.ReactNode;
    location?: Partial<Location> | string;
}
/**
 * A container for a nested tree of <Route> elements that renders the branch
 * that best matches the current location.
 *
 * @see https://reactrouter.com/docs/en/v6/components/routes
 */
export declare function Routes({ children, location, }: RoutesProps): React.ReactElement | null;
export interface DeferredResolveRenderFunction<Data> {
    (data: ResolvedDeferrable<Data>): JSX.Element;
}
export interface DeferredProps<Data> extends Omit<React.SuspenseProps, "children"> {
    children: React.ReactNode | DeferredResolveRenderFunction<Data>;
    value: Data;
    errorElement?: React.ReactNode;
}
/**
 * Component to use for rendering lazily loaded data from returning deferred()
 * in a loader function
 */
export declare function Deferred<Data = any>({ children, value, fallback, errorElement, }: DeferredProps<Data>): JSX.Element;
export interface ResolveDeferredProps<Data> {
    children: DeferredResolveRenderFunction<Data>;
}
/**
 * @private
 */
export declare function ResolveDeferred<Data>({ children, }: ResolveDeferredProps<Data>): JSX.Element;
/**
 * Creates a route config from a React "children" object, which is usually
 * either a `<Route>` element or an array of them. Used internally by
 * `<Routes>` to create a route config from its children.
 *
 * @see https://reactrouter.com/docs/en/v6/utils/create-routes-from-children
 */
export declare function createRoutesFromChildren(children: React.ReactNode, parentPath?: number[]): RouteObject[];
/**
 * Renders the result of `matchRoutes()` into a React element.
 */
export declare function renderMatches(matches: RouteMatch[] | null): React.ReactElement | null;
export {};
